package com.gic.plug.web.controller;

import java.util.*;
import java.util.stream.Collectors;

import com.gic.enterprise.dto.EnterpriseDTO;
import com.gic.enterprise.service.EnterpriseApiService;
import com.gic.plug.web.vo.widget.StoreWidgetInterfaceShareVO;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.plug.web.utils.storeresourceauth.StoreResourceUtils;
import com.gic.store.constant.StoreESFieldsEnum;
import com.gic.store.dto.StoreBrandDTO;
import com.gic.store.service.StoreBrandApiService;

/**
 * 门店选择器-店招品牌查询
 * @ClassName:
 * @Description:  
 * @author guojuxing 
 * @date 2021/1/14 6:50 PM 
 */
@RestController
@RequestMapping("/store-brand")
public class StoreBrandController {

    @Autowired
    private StoreBrandApiService storeBrandApiService;
    @Autowired
    private EnterpriseApiService enterpriseApiService;

    @RequestMapping("/list-store-brand")
    public RestResponse listStoreBrand(String search) {
        Integer enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId();
        ServiceResponse<List<StoreBrandDTO>> serviceResponse = storeBrandApiService.listAllStoreBrand(enterpriseId, search);
        if (serviceResponse.isSuccess()) {
            List<StoreBrandDTO> list = StoreResourceUtils.auth(
                    serviceResponse.getResult(),
                    StoreESFieldsEnum.STOREBRANDIDLIST.getField());

            List<StoreWidgetInterfaceShareVO> voList = new ArrayList<>();
            if (CollectionUtils.isNotEmpty(list)) {
                //共享类型
                List<Integer> brandIdList = list.stream().filter(e -> Objects.equals(e.getType(), 2))
                        .mapToInt(e -> e.getStoreBrandId())
                        .boxed()
                        .collect(Collectors.toList());

                Map<Integer, String> enterpriseMap = new HashMap<>();
                Map<Integer, Integer> brandIdMap = new HashMap<>();

                ServiceResponse<List<StoreBrandDTO>> brandResponse = storeBrandApiService.listAllStoreBrandInfoByIds(brandIdList);
                if (brandResponse.isSuccess() && CollectionUtils.isNotEmpty(brandResponse.getResult())) {
                    List<StoreBrandDTO> brandList = brandResponse.getResult();
                    List<Integer> enterpriseIdList = brandList.stream()
                            .filter(e -> Objects.equals(e.getType(), 1))
                            .mapToInt(e -> e.getEnterpriseId()).boxed()
                            .collect(Collectors.toList());
                    brandIdMap = brandList.stream().filter(e -> Objects.equals(e.getType(), 1))
                            .collect(Collectors.toMap(e -> e.getStoreBrandId(), e -> e.getEnterpriseId()));

                    ServiceResponse<List<EnterpriseDTO>> enterpriseResponse = enterpriseApiService.listEnterpriseByIds(enterpriseIdList);
                    if (enterpriseResponse.isSuccess()) {
                        enterpriseMap = enterpriseResponse.getResult().stream().collect(Collectors.toMap(e -> e.getEnterpriseId(), e -> e.getEnterpriseName()));
                    }
                }

                Map<Integer, String> finalEnterpriseMap = enterpriseMap;
                Map<Integer, Integer> finalBrandIdMap = brandIdMap;
                voList = list.stream()
                        .map(e -> {
                            StoreWidgetInterfaceShareVO vo = new StoreWidgetInterfaceShareVO();
                            vo.setLabel(e.getStoreBrandName());
                            vo.setValue(e.getStoreBrandId().toString());
                            //共享类型
                            if (Objects.equals(e.getType(), 2)) {
                                Integer tempEnterpriseId = finalBrandIdMap.get(e.getStoreBrandId());
                                vo.setEnterpriseName(finalEnterpriseMap.get(tempEnterpriseId));
                            }
                            return vo;
                        })
                        .collect(Collectors.toList());
            }
            return RestResponse.success(voList);
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }
}
